@@ -58,7 +58,7 @@ function usage() {
           + "-enable-script-debugger          Enables the script debugger.\n"
           + "                                 NOT recommended as this may cause unexpected\n"
           + "                                 behavior when using QCAD.\n"
-          + "-debug-action-order              Print action oder information in menus\n"
+          + "-debug-action-order              Print action order information in menus\n"
           + "-exec [script file] [options]    Executes the given script file directly\n"
           + "                                 after staring QCAD. Options after the script\n"
           + "                                 file are passed on to the script.\n"
@@ -271,6 +271,7 @@ function setUpDragAndDrop(appWin) {
     });
 
     appWin.drop.connect(function(evt) {
+        // workaround for Qt keyboard focus bug:
         var appWin = RMainWindowQt.getMainWindow();
         if (!isNull(appWin)) {
             appWin.activateWindow();
@@ -304,6 +305,10 @@ function loadTranslations(addOns, splash) {
 
     // load C++ translations:
     var modules = ["qt", "assistant", "qt_help", "qcadcore", "qcadentity", "qcadgui"];
+    if (RSettings.isQt(5)) {
+        modules.unshift("qtbase");
+    }
+
     for (var mi=0; mi<modules.length; ++mi) {
         var module = modules[mi];
 
@@ -382,10 +387,10 @@ function initAddOns(addOns, splash) {
 }
 
 function postInitAddOns(addOns, splash) {
-    if (!isNull(splash)) {
-        splash.showMessage(qsTr("Post-initializing add-ons...") + "\n", Qt.AlignBottom);
-        QCoreApplication.processEvents();
-    }
+//    if (!isNull(splash)) {
+//        splash.showMessage(qsTr("Post-initializing add-ons...") + "\n", Qt.AlignBottom);
+//        QCoreApplication.processEvents();
+//    }
 
     var addOn;
     var i;
@@ -582,6 +587,7 @@ function main() {
 
         var pixmap = new QPixmap(fn);
         splash = new QSplashScreen(pixmap);
+        splash.objectName = "Splash";
         if (!QCoreApplication.arguments().contains("-no-show")) {
             splash.show();
         }
@@ -695,14 +701,14 @@ function main() {
         appWin.show();
     }
 
-    postInitAddOns(addOns, splash);
-    RPluginLoader.postInitPlugins(RPluginInterface.GotMainWindow);
-
     if (!isNull(splash)) {
         splash.close();
         splash.destroy();
     }
 
+    postInitAddOns(addOns);
+    RPluginLoader.postInitPlugins(RPluginInterface.GotMainWindow);
+
     // if the window position / size was not read from a config file,
     // automatically position property editor and library browser (first start):
     if (isFirstStart) {
